@@ -59,7 +59,7 @@ class Exceptions:
 
 class ChimeSDKIdentityClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html)
     """
 
@@ -75,7 +75,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#can_paginate)
         """
 
@@ -84,13 +84,13 @@ class ChimeSDKIdentityClient(BaseClient):
         *,
         Name: str,
         ClientRequestToken: str,
-        Metadata: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Metadata: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateAppInstanceResponseTypeDef:
         """
         Creates an Amazon Chime SDK messaging `AppInstance` under an AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#create_app_instance)
         """
 
@@ -100,7 +100,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Promotes an `AppInstanceUser` to an `AppInstanceAdmin`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_admin)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_admin)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#create_app_instance_admin)
         """
 
@@ -111,13 +111,13 @@ class ChimeSDKIdentityClient(BaseClient):
         AppInstanceUserId: str,
         Name: str,
         ClientRequestToken: str,
-        Metadata: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Metadata: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateAppInstanceUserResponseTypeDef:
         """
         Creates a user under an Amazon Chime `AppInstance`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#create_app_instance_user)
         """
 
@@ -125,7 +125,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Deletes an `AppInstance` and all associated data asynchronously.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#delete_app_instance)
         """
 
@@ -133,7 +133,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Demotes an `AppInstanceAdmin` to an `AppInstanceUser`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_admin)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_admin)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#delete_app_instance_admin)
         """
 
@@ -141,7 +141,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Deletes an `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#delete_app_instance_user)
         """
 
@@ -149,7 +149,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Returns the full details of an `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance)
         """
 
@@ -159,7 +159,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Returns the full details of an `AppInstanceAdmin` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_admin)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_admin)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance_admin)
         """
 
@@ -169,21 +169,21 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Returns the full details of an `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance_user)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#generate_presigned_url)
         """
 
@@ -193,37 +193,37 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Gets the retention settings for an `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.get_app_instance_retention_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.get_app_instance_retention_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#get_app_instance_retention_settings)
         """
 
     def list_app_instance_admins(
-        self, *, AppInstanceArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstanceAdminsResponseTypeDef:
         """
         Returns a list of the administrators in the `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_admins)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_admins)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instance_admins)
         """
 
     def list_app_instance_users(
-        self, *, AppInstanceArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstanceUsersResponseTypeDef:
         """
         List all `AppInstanceUsers` created under a single `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instance_users)
         """
 
     def list_app_instances(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstancesResponseTypeDef:
         """
         Lists all Amazon Chime `AppInstance` s created under a single AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instances)
         """
 
@@ -236,7 +236,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Sets the amount of time in days that a given `AppInstance` retains data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.put_app_instance_retention_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.put_app_instance_retention_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#put_app_instance_retention_settings)
         """
 
@@ -246,7 +246,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Updates `AppInstance` metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#update_app_instance)
         """
 
@@ -256,6 +256,6 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Updates the details of an `AppInstanceUser`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#update_app_instance_user)
         """
